summaryrefslogtreecommitdiff
path: root/mysql-test
diff options
context:
space:
mode:
authorunknown <tsmith@quadxeon.mysql.com>2007-03-20 20:59:41 +0100
committerunknown <tsmith@quadxeon.mysql.com>2007-03-20 20:59:41 +0100
commit6bb78b95de18db26922861d38dfc25f219c198e0 (patch)
tree5cc5809ce40d2df0b1eff234f1ba66740c6ad570 /mysql-test
parent971124a7f577831b37df688ba130c4f9c2a86d9e (diff)
parent23fa1ee874377dc8eea55da2a3511554a4ed776e (diff)
downloadmariadb-git-6bb78b95de18db26922861d38dfc25f219c198e0.tar.gz
Merge tsmith@bk-internal.mysql.com:/home/bk/mysql-5.0-build
into quadxeon.mysql.com:/benchmarks/ext3/TOSAVE/tsmith/bk/mar20/maint/50
Diffstat (limited to 'mysql-test')
-rw-r--r--mysql-test/install_test_db.sh20
-rwxr-xr-xmysql-test/mysql-test-run.pl14
-rw-r--r--mysql-test/r/delayed.result5
-rw-r--r--mysql-test/r/loaddata.result6
-rw-r--r--mysql-test/r/merge.result5
-rw-r--r--mysql-test/t/delayed.test10
-rw-r--r--mysql-test/t/init_connect.test5
-rw-r--r--mysql-test/t/loaddata.test4
-rw-r--r--mysql-test/t/merge.test9
-rw-r--r--mysql-test/t/mysqlbinlog-cp932.test2
10 files changed, 44 insertions, 36 deletions
diff --git a/mysql-test/install_test_db.sh b/mysql-test/install_test_db.sh
index 75388769808..716f7f31383 100644
--- a/mysql-test/install_test_db.sh
+++ b/mysql-test/install_test_db.sh
@@ -22,7 +22,7 @@ if [ x$1 = x"--bin" ]; then
BINARY_DIST=1
bindir=../bin
- scriptdir=../bin
+ scriptdir=bin
libexecdir=../libexec
# Check if it's a binary distribution or a 'make install'
@@ -33,7 +33,7 @@ if [ x$1 = x"--bin" ]; then
then
execdir=../../sbin
bindir=../../bin
- scriptdir=../../bin
+ scriptdir=../bin
libexecdir=../../libexec
else
execdir=../bin
@@ -43,7 +43,7 @@ else
execdir=../sql
bindir=../client
fix_bin=.
- scriptdir=../scripts
+ scriptdir=scripts
libexecdir=../libexec
fi
@@ -100,18 +100,14 @@ if [ x$BINARY_DIST = x1 ] ; then
basedir=..
else
basedir=.
-EXTRA_ARG="--language=../sql/share/english/ --character-sets-dir=../sql/share/charsets/"
+EXTRA_ARG="--windows"
fi
-mysqld_boot="${MYSQLD_BOOTSTRAP-$mysqld}"
+INSTALL_CMD="$scriptdir/mysql_install_db --no-defaults $EXTRA_ARG --basedir=$basedir --datadir=mysql-test/$ldata --srcdir=."
+echo "running $INSTALL_CMD"
-mysqld_boot="$mysqld_boot --no-defaults --bootstrap --skip-grant-tables \
- --basedir=$basedir --datadir=$ldata \
- --skip-innodb --skip-ndbcluster --skip-bdb \
- $EXTRA_ARG"
-echo "running $mysqld_boot"
-
-if $scriptdir/mysql_create_system_tables test $mdata $hostname | $mysqld_boot
+cd ..
+if $INSTALL_CMD
then
exit 0
else
diff --git a/mysql-test/r/delayed.result b/mysql-test/r/delayed.result
index 82a308c63e7..b37679847be 100644
--- a/mysql-test/r/delayed.result
+++ b/mysql-test/r/delayed.result
@@ -250,3 +250,8 @@ SELECT HEX(a) FROM t1;
HEX(a)
1
DROP TABLE t1;
+CREATE TABLE t1(c1 INT) ENGINE=MyISAM;
+CREATE TABLE t2(c1 INT) ENGINE=MERGE UNION=(t1);
+INSERT DELAYED INTO t2 VALUES(1);
+ERROR HY000: Table storage engine for 't2' doesn't have this option
+DROP TABLE t1, t2;
diff --git a/mysql-test/r/loaddata.result b/mysql-test/r/loaddata.result
index 83c7b37d914..bef483569d4 100644
--- a/mysql-test/r/loaddata.result
+++ b/mysql-test/r/loaddata.result
@@ -148,11 +148,11 @@ MYSQLTEST_VARDIR/
set @@secure_file_priv= 0;
ERROR HY000: Variable 'secure_file_priv' is a read only variable
truncate table t1;
-load data infile 'MYSQL_TEST_DIR/Makefile' into table t1;
+load data infile 'MYSQL_TEST_DIR/t/loaddata.test' into table t1;
ERROR HY000: The MySQL server is running with the --secure-file-priv option so it cannot execute this statement
select * from t1;
a b c
-select load_file("MYSQL_TEST_DIR/Makefile");
-load_file("MYSQL_TEST_DIR/Makefile")
+select load_file("MYSQL_TEST_DIR/t/loaddata.test");
+load_file("MYSQL_TEST_DIR/t/loaddata.test")
NULL
drop table t1, t2;
diff --git a/mysql-test/r/merge.result b/mysql-test/r/merge.result
index e45e5853c0c..c4419d64a65 100644
--- a/mysql-test/r/merge.result
+++ b/mysql-test/r/merge.result
@@ -803,11 +803,6 @@ CREATE TABLE tm1(a SMALLINT, b SMALLINT, KEY(a)) ENGINE=MERGE UNION=(t1);
SELECT * FROM tm1;
ERROR HY000: Unable to open underlying table which is differently defined or of non-MyISAM type or doesn't exist
DROP TABLE t1, tm1;
-CREATE TABLE t1(c1 INT) ENGINE=MyISAM;
-CREATE TABLE t2(c1 INT) ENGINE=MERGE UNION=(t1);
-INSERT DELAYED INTO t2 VALUES(1);
-ERROR HY000: Table storage engine for 't2' doesn't have this option
-DROP TABLE t1, t2;
CREATE TABLE t1(c1 VARCHAR(1));
CREATE TABLE m1 LIKE t1;
ALTER TABLE m1 ENGINE=MERGE UNION=(t1);
diff --git a/mysql-test/t/delayed.test b/mysql-test/t/delayed.test
index 773927f6015..13615c8c269 100644
--- a/mysql-test/t/delayed.test
+++ b/mysql-test/t/delayed.test
@@ -242,3 +242,13 @@ INSERT DELAYED INTO t1 VALUES(1);
FLUSH TABLE t1;
SELECT HEX(a) FROM t1;
DROP TABLE t1;
+
+#
+# Bug#26464 - insert delayed + update + merge = corruption
+#
+CREATE TABLE t1(c1 INT) ENGINE=MyISAM;
+CREATE TABLE t2(c1 INT) ENGINE=MERGE UNION=(t1);
+--error 1031
+INSERT DELAYED INTO t2 VALUES(1);
+DROP TABLE t1, t2;
+
diff --git a/mysql-test/t/init_connect.test b/mysql-test/t/init_connect.test
index c9a18a4003d..0a08559279c 100644
--- a/mysql-test/t/init_connect.test
+++ b/mysql-test/t/init_connect.test
@@ -2,10 +2,11 @@
# Test of init_connect variable
#
+# should work with embedded server after mysqltest is fixed
+--source include/not_embedded.inc
+
--source include/add_anonymous_users.inc
-# should work with embedded server after mysqltest is fixed
--- source include/not_embedded.inc
connect (con0,localhost,root,,);
connection con0;
select hex(@a);
diff --git a/mysql-test/t/loaddata.test b/mysql-test/t/loaddata.test
index 0dc91c36a09..125a65826ca 100644
--- a/mysql-test/t/loaddata.test
+++ b/mysql-test/t/loaddata.test
@@ -126,12 +126,12 @@ set @@secure_file_priv= 0;
truncate table t1;
--replace_result $MYSQL_TEST_DIR MYSQL_TEST_DIR
--error 1290
-eval load data infile '$MYSQL_TEST_DIR/Makefile' into table t1;
+eval load data infile '$MYSQL_TEST_DIR/t/loaddata.test' into table t1;
select * from t1;
# Test "load_file" returns NULL
--replace_result $MYSQL_TEST_DIR MYSQL_TEST_DIR
-eval select load_file("$MYSQL_TEST_DIR/Makefile");
+eval select load_file("$MYSQL_TEST_DIR/t/loaddata.test");
# cleanup
drop table t1, t2;
diff --git a/mysql-test/t/merge.test b/mysql-test/t/merge.test
index 07923fa020c..490010c0a42 100644
--- a/mysql-test/t/merge.test
+++ b/mysql-test/t/merge.test
@@ -430,16 +430,7 @@ CREATE TABLE tm1(a SMALLINT, b SMALLINT, KEY(a)) ENGINE=MERGE UNION=(t1);
SELECT * FROM tm1;
DROP TABLE t1, tm1;
-#
-# Bug#26464 - insert delayed + update + merge = corruption
-#
-CREATE TABLE t1(c1 INT) ENGINE=MyISAM;
-CREATE TABLE t2(c1 INT) ENGINE=MERGE UNION=(t1);
---error 1031
-INSERT DELAYED INTO t2 VALUES(1);
-DROP TABLE t1, t2;
-#
# BUG#26881 - Large MERGE tables report incorrect specification when no
# differences in tables
#
diff --git a/mysql-test/t/mysqlbinlog-cp932.test b/mysql-test/t/mysqlbinlog-cp932.test
index 0e0a4e2bfae..1487606a6c2 100644
--- a/mysql-test/t/mysqlbinlog-cp932.test
+++ b/mysql-test/t/mysqlbinlog-cp932.test
@@ -1,3 +1,5 @@
+# disabled in embedded until tools running is fixed with embedded
+--source include/not_embedded.inc
-- source include/have_cp932.inc
# Bug#16217 (mysql client did not know how not switch its internal charset)
diff --git a/mysql-test/mysql-test-run.pl b/mysql-test/mysql-test-run.pl
index 565c55b14fd..fadb7c5f0e0 100755
--- a/mysql-test/mysql-test-run.pl
+++ b/mysql-test/mysql-test-run.pl
@@ -1495,9 +1495,17 @@ sub executable_setup () {
if (!$opt_extern)
{
- # Look for SQL scripts directory
- $path_sql_dir= mtr_path_exists("$glob_basedir/share",
- "$glob_basedir/scripts");
+ # Look for SQL scripts directory
+ if ( mtr_file_exists("$path_share/mysql_system_tables.sql") ne "")
+ {
+ # The SQL scripts are in path_share
+ $path_sql_dir= $path_share;
+ }
+ else
+ {
+ $path_sql_dir= mtr_path_exists("$glob_basedir/share",
+ "$glob_basedir/scripts");
+ }
if ( $mysql_version_id >= 50100 ) {
$exe_mysqlslap= mtr_exe_exists("$path_client_bindir/mysqlslap");